@@ -10,10 +10,12 @@ base class over the original APISession class.
     :members:
     :inherited-members:
 '''
+import os
+import warnings
 from restfly import APISession as Base
+from tenable.errors import AuthenticationWarning
 from tenable.utils import url_validator
 from tenable.version import version
-import os, warnings
 
 
 class APIPlatform(Base):
@@ -34,7 +36,8 @@ class APIPlatform(Base):
         box_attrs (dict, optional):
             Any additional attributes to pass to the Box constructor for this
             session?  For a list of attributes that can be sent, please refer
-            to the `Box documentation <https://github.com/cdgriffith/Box/wiki>`_
+            to the
+            `Box documentation <https://github.com/cdgriffith/Box/wiki>`_
             for more information.
         build (str, optional):
             The build number to put into the User-Agent string.
@@ -69,116 +72,114 @@ class APIPlatform(Base):
     '''
     _lib_name = 'pyTenable'
     _lib_version = version
-    _box = True
     _backoff = 1
     _retries = 5
     _env_base = ''
-    _port = 443
-    _scheme = 'https'
-    _address = None
-    _auth = (None, None)
+    _auth = {}
     _auth_mech = None
-    _box_attrs = dict()
 
     def __init__(self, **kwargs):
-        # Constructing the URL from the various parameters.
-        self._url = '{}://{}:{}'.format(
-            kwargs.get('scheme', self._scheme),
-            kwargs.get('address', os.getenv(
-                '{}_ADDRESS'.format(self._env_base), self._address)),
-            kwargs.get('port', os.getenv(
-                '{}_PORT'.format(self._env_base), self._port)),
-        )
 
         # if the constructed URL isn't valid, then we will throw a TypeError
         # to inform the caller that something isn't right here.
+        self._url = kwargs.get('url',
+                               os.environ.get(f'{self._env_base}_URL',
+                                              self._url
+                                              )
+                               )
         if not url_validator(self._url):
-            raise TypeError('{url} is not a valid URL'.format(url=self._url))
+            raise TypeError(f'{self._url} is not a valid URL')
 
         # CamelCase squashing is an optional parameter thanks to Box.  if the
-        # user has requested it, then we should add the appropriate parameter to
-        # the box_attrs.
+        # user has requested it, then we should add the appropriate parameter
+        # to the box_attrs.
         if kwargs.get('squash_camel'):
             box_attrs = kwargs.get('box_attrs', {})
             box_attrs['camel_killer_box'] = bool(kwargs.pop('squash_camel'))
             kwargs['box_attrs'] = box_attrs
 
         # Call the RESTfly constructor
-        super(APIPlatform, self).__init__(**kwargs)
+        super().__init__(**kwargs)
+
+    def _session_auth(self, username, password):
+        '''
+        Default Session auth behavior
+        '''
+        self.post('session', json={
+            'username': username,
+            'password': password
+        })
+        self._auth_mech = 'user'
+
+    def _key_auth(self, access_key, secret_key):
+        '''
+        Default API Key Auth Behavior
+        '''
+        self._session.headers.update({
+            'X-APIKeys': f'accessKey={access_key}; secretKey={secret_key}'
+        })
+        self._auth_mech = 'keys'
 
     def _authenticate(self, **kwargs):
         '''
         This method handles authentication for both API Keys and for session
         authentication.
         '''
-
-        # These functions determine how authentication is to be handled within
-        # for both session authentication and key-based authentication.  They
-        # have been broken down into these functions for easy overloading.
-        def key_auth():
-            '''
-            Default API Key Auth Behavior
-            '''
-            self._session.headers.update({
-                'X-APIKeys': 'accessKey={}; secretKey={}'.format(*keys)
-            })
-            self._auth_mech = 'keys'
-
-        def s_auth():
-            '''
-            Default Session auth behavior
-            '''
-            self.post('session', json={
-                'username': self._auth[0],
-                'password': self._auth[1]
-            })
-            self._auth_mech = 'user'
-
         # Here we are grafting the authentication functions into the keyword
         # arguments for later usage.  If a function is provided in the keywords
         # under the key names below, we will use those instead.  This should
         # essentially allow for the authentication logic to be overridden with
         # minimal effort.
-        kwargs['key_auth_func'] = kwargs.get('key_auth_func', key_auth)
-        kwargs['session_auth_func'] = kwargs.get('session_auth_func', s_auth)
+        kwargs['key_auth_func'] = kwargs.get('key_auth_func',
+                                             self._key_auth)
+        kwargs['session_auth_func'] = kwargs.get('session_auth_func',
+                                                 self._session_auth)
 
-        # Pull the API keys from the keyword arguments passed to the constructor
-        # and build the keys tuple.  As API Keys will be injected directly into
-        # the session, there is no need to store these.
-        keys = (
-            kwargs.get('access_key', os.getenv(
-                '{}_ACCESS_KEY'.format(self._env_base))),
-            kwargs.get('secret_key', os.getenv(
-                '{}_SECRET_KEY'.format(self._env_base)))
-        )
+        # Pull the API keys from the keyword arguments passed to the
+        # constructor and build the keys tuple.  As API Keys will be
+        # injected directly into the session, there is no need to store these.
+        keys = kwargs.get('_key_auth_dict', {
+            'access_key': kwargs.get('access_key',
+                                     os.getenv(f'{self._env_base}_ACCESS_KEY')
+                                     ),
+            'secret_key': kwargs.get('secret_key',
+                                     os.getenv(f'{self._env_base}_SECRET_KEY')
+                                     )
+        })
 
         # The session authentication tuple.  We will be storing these as its
         # possible for the session to timeout on the user.  This would require
         # re-authentication.
-        self._auth = (
-            kwargs.get('username', os.getenv(
-                '{}_USERNAME'.format(self._env_base))),
-            kwargs.get('password', os.getenv(
-                '{}_PASSWORD'.format(self._env_base)))
-        )
+        self._auth = kwargs.get('_session_auth_dict', {
+            'username': kwargs.get('username',
+                                   os.getenv(f'{self._env_base}_USERNAME')
+                                   ),
+            'password': kwargs.get('password',
+                                   os.getenv(f'{self._env_base}_PASSWORD')
+                                   )
+        })
 
         # Run the desired authentication function.  As API keys are generally
-        # preferred over session authentication, we will first check to see that
-        # keys have been
-        if None not in keys:
-            kwargs['key_auth_func']()
-        elif None not in self._auth:
-            kwargs['session_auth_func']()
+        # preferred over session authentication, we will first check to see
+        # that keys have been set, as we prefer stateless auth to stateful.
+        if None not in [v for _, v in keys.items()]:
+            kwargs['key_auth_func'](**keys)
+        elif None not in [v for _, v in self._auth.items()]:
+            kwargs['session_auth_func'](**self._auth)
         else:
-            warnings.warn('Starting an unauthenticated session')
+            warnings.warn('Starting an unauthenticated session',
+                          AuthenticationWarning)
             self._log.warning('Starting an unauthenticated session.')
 
-    def _deauthenticate(self):
+    def _deauthenticate(self,  # noqa PLW0221
+                        method: str = 'DELETE',
+                        path: str = 'session'
+                        ):
         '''
         This method handles de-authentication.  This is only necessary for
         session-based authentication.
         '''
         if self._auth_mech == 'user':
-            self.delete('session')
-        self._auth = (None, None)
+            self._req(method, path)
+        self._auth = {}
         self._auth_mech = None
