@@ -1,5 +1,5 @@
 '''
-policies
+Policies
 ========
 
 The following methods allow for interaction into the Tenable.io
@@ -9,15 +9,7 @@ Methods available on ``tio.policies``:
 
 .. rst-class:: hide-signature
 .. autoclass:: PoliciesAPI
-
-    .. automethod:: configure
-    .. automethod:: copy
-    .. automethod:: create
-    .. automethod:: delete
-    .. automethod:: details
-    .. automethod:: policy_import
-    .. automethod:: policy_export
-    .. automethod:: list
+    :members:
 '''
 from .base import TIOEndpoint
 from tenable.utils import policy_settings, dict_merge
@@ -241,7 +233,7 @@ class PoliciesAPI(TIOEndpoint):
 
         Examples:
             >>> with open('example.nessus') as policy:
-            ...     tio.policies.import(policy)
+            ...     tio.policies.policy_import(policy)
         '''
         fid = self._api.files.upload(fobj)
         return self._api.post('policies/import', json={'file': fid}).json()
@@ -266,7 +258,7 @@ class PoliciesAPI(TIOEndpoint):
 
         Examples:
             >>> with open('example.nessus', 'wb') as policy:
-            ...     tio.policies.export(1, policy)
+            ...     tio.policies.policy_export(1, policy)
         '''
         # If no file object was givent to us, then lets create a new BytesIO
         # object to dump the data into.
