@@ -824,7 +824,7 @@ class ScansAPI(TIOEndpoint):
             scan_id (int or uuid): The unique identifier for the scan.
             history_id (int, optional):
                 The unique identifier for the instance of the scan.
-            history_uuid (uuid, optional):
+            history_uuid (uuid, optional)
                 The UUID for the instance of the scan.
 
         Returns:
@@ -834,11 +834,16 @@ class ScansAPI(TIOEndpoint):
         Examples:
             Retrieve the latest results:
 
-            >>> results = tio.scans.results(1)
+            >>> results = tio.scans.results(419)
 
-            Retrieve a specific instance of the result set:
+            Retrieve a specific instance of the result set using history_id:
+
+            >>> results = tio.scans.results(419, history_id=15184619)
+
+            Retrieve a specific instance of the result set using history_uuid:
+
+            >>> results = tio.scans.results(419, history_uuid="123e4567-e89b-12d3-a456-426614174000")
 
-            >>> results = tio.scans.results(1, 1)
         '''
         params = dict()
 
@@ -846,8 +851,7 @@ class ScansAPI(TIOEndpoint):
             params['history_id'] = self._check('history_id', history_id, int)
 
         if history_uuid:
-            params['history_uuid'] = self._check(
-                'history_uuid', history_uuid, 'scanner-uuid')
+            params['history_id'] = self._check('history_uuid', history_uuid, "uuid")
 
         return self._api.get('scans/{}'.format(
             scan_id), params=params).json()
