@@ -1,5 +1,5 @@
 '''
-server
+Server
 ======
 
 The following methods allow for interaction into the Tenable.io
@@ -9,9 +9,7 @@ Methods available on ``tio.server``:
 
 .. rst-class:: hide-signature
 .. autoclass:: ServerAPI
-
-    .. automethod:: properties
-    .. automethod:: status
+    :members:
 '''
 from .base import TIOEndpoint
 
@@ -46,4 +44,4 @@ class ServerAPI(TIOEndpoint):
             >>> status = tio.server.status()
             >>> pprint(status)
         '''
-        return self._api.get('server/status').json()
\ No newline at end of file
+        return self._api.get('server/status').json()
