@@ -1,5 +1,5 @@
 '''
-files
+Files
 =====
 
 The following methods allow for interaction into the Tenable.sc
@@ -9,9 +9,7 @@ Methods available on ``sc.files``:
 
 .. rst-class:: hide-signature
 .. autoclass:: FileAPI
-
-    .. automethod:: clear
-    .. automethod:: upload
+    :members:
 '''
 from .base import SCEndpoint
 
@@ -49,4 +47,4 @@ class FileAPI(SCEndpoint):
         '''
         return self._api.post('file/clear', json={
             'filename': self._check('filename', filename, str)
-        }).json()['response']['filename']
\ No newline at end of file
+        }).json()['response']['filename']
